@@ -2,7 +2,8 @@
 NULL
 
 #' @importFrom R6 R6Class
-HandlerStack <- R6Class('HandlerStack',
+HandlerStack <- R6Class(
+  'HandlerStack',
   public = list(
     # Methods
     initialize = function(server = NULL) {
@@ -11,8 +12,12 @@ HandlerStack <- R6Class('HandlerStack',
     add = function(handler, id, pos = NULL) {
       check_string(id)
       check_function(handler)
-      if (!rlang::is_primitive(handler) && ".request" %in% fn_fmls_names(handler)) {
-        cli::cli_abort("{.arg request} is a reserved argument name and cannot be used in event handlers")
+      if (
+        !rlang::is_primitive(handler) && ".request" %in% fn_fmls_names(handler)
+      ) {
+        cli::cli_abort(
+          "{.arg request} is a reserved argument name and cannot be used in event handlers"
+        )
       }
       if (is.null(pos)) {
         pos <- length(private$handlers)
@@ -20,7 +25,11 @@ HandlerStack <- R6Class('HandlerStack',
         check_number_whole(pos, min = 1)
         pos <- max(0, min(c(pos - 1, length(private$handlers))))
       }
-      private$handlers <- append(private$handlers, set_names(list(handler), id), pos)
+      private$handlers <- append(
+        private$handlers,
+        set_names(list(handler), id),
+        pos
+      )
     },
     remove = function(id) {
       check_string(id)
